==> tdesdk-trinity_14.1.1.orig.tar.xz: tdesdk-trinity-14.1.1/kbabel/kbabeldict/modules/tmx/pc_factory.cpp <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
		2002 by Stanislav Visnovsky <visnovsky@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.
		
**************************************************************************** */


#include <tdelocale.h>
#include <kinstance.h>
#include <tdeaboutdata.h>
#include <kdebug.h>

#include "pc_factory.h"
#include "tmxcompendium.h"


extern "C"
{
	KDE_EXPORT void *init_kbabeldict_tmxcompendium()
	{
		return new PcFactory;
	}
}


TDEInstance *PcFactory::s_instance = 0;
TDEAboutData *PcFactory::s_about = 0;


PcFactory::PcFactory( TQObject *parent, const char *name)
		: KLibFactory(parent,name)
{
}

PcFactory::~PcFactory()
{
	if(s_instance)
	{
		delete s_instance;
		s_instance=0;
	}

	if(s_about)
	{
		delete s_about;
		s_about=0;
	}
}


TQObject *PcFactory::createObject( TQObject *parent, const char *name
				, const char *classname, const TQStringList &)
{
	if(TQCString(classname) != "SearchEngine")
	{
		kdError() << "not a SearchEngine requested" << endl;
		return 0;
	}
	
	return new TmxCompendium(parent,name);
}


TDEInstance *PcFactory::instance()
{
	if(!s_instance)
	{
		s_about = new TDEAboutData( "tmxcompendium", I18N_NOOP("TMX Compendium")
						, "1.0"
						, I18N_NOOP("A module for searching in a TMX file")
						, TDEAboutData::License_GPL
						, "Copyright 2002, Stanislav Visnovsky"
						,0,0, "visnovsky@kde.org");

		s_about->addAuthor("Matthias Kiefer",0,"kiefer@kde.org");
		s_about->addAuthor("Stanislav Visnovsky",0,"visnovsky@kde.org");
		
		s_instance = new TDEInstance(s_about);
	}

	return s_instance;
}

#include "pc_factory.moc"

==> tdesdk-trinity-14.1.4.tar.xz: tdesdk-trinity-14.1.4/kbabel/kbabeldict/modules/tmx/pc_factory.cpp <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
		2002 by Stanislav Visnovsky <visnovsky@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.
		
**************************************************************************** */


#include <tdelocale.h>
#include <kinstance.h>
#include <tdeaboutdata.h>
#include <kdebug.h>

#include "pc_factory.h"
#include "tmxcompendium.h"


extern "C"
{
	TDE_EXPORT void *init_kbabeldict_tmxcompendium()
	{
		return new PcFactory;
	}
}


TDEInstance *PcFactory::s_instance = 0;
TDEAboutData *PcFactory::s_about = 0;


PcFactory::PcFactory( TQObject *parent, const char *name)
		: KLibFactory(parent,name)
{
}

PcFactory::~PcFactory()
{
	if(s_instance)
	{
		delete s_instance;
		s_instance=0;
	}

	if(s_about)
	{
		delete s_about;
		s_about=0;
	}
}


TQObject *PcFactory::createObject( TQObject *parent, const char *name
				, const char *classname, const TQStringList &)
{
	if(TQCString(classname) != "SearchEngine")
	{
		kdError() << "not a SearchEngine requested" << endl;
		return 0;
	}
	
	return new TmxCompendium(parent,name);
}


TDEInstance *PcFactory::instance()
{
	if(!s_instance)
	{
		s_about = new TDEAboutData( "tmxcompendium", I18N_NOOP("TMX Compendium")
						, "1.0"
						, I18N_NOOP("A module for searching in a TMX file")
						, TDEAboutData::License_GPL
						, "Copyright 2002, Stanislav Visnovsky"
						,0,0, "visnovsky@kde.org");

		s_about->addAuthor("Matthias Kiefer",0,"kiefer@kde.org");
		s_about->addAuthor("Stanislav Visnovsky",0,"visnovsky@kde.org");
		
		s_instance = new TDEInstance(s_about);
	}

	return s_instance;
}

#include "pc_factory.moc"
